CanvasObject class abstract
Base class for retained canvas objects.
- Implementers
Constructors
- CanvasObject({String? id, String? name, CanvasPaint paint = const CanvasPaint(), double rotation = 0, bool locked = false, })
-
Creates a retained canvas object.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
Whether this object is hidden from drawing and pointer hit testing.
final
- id → String?
-
Optional app-level object identifier.
final
- locked → bool
-
Whether this object can be selected but not edited.
final
- name → String?
-
Optional display name for layer panels.
final
- paint → CanvasPaint
-
Paint settings for this object.
final
- rotation → double
-
Clockwise rotation in degrees.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
Object type name used for JSON serialization.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Converts this object to a JSON-friendly map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited