FlintElement class
DOM element node with a tag, properties, and children.
- Inheritance
- Implementers
- Alert
- AnimatedContainer
- AppShell
- AspectRatioBox
- Audio
- AuthShell
- Avatar
- BarChart
- Box
- Breadcrumbs
- Button
- ButtonGroup
- Canvas
- Center
- Checkbox
- Column
- ConfirmAction
- ConstrainedBox
- Container
- DashboardShell
- DatePicker
- DateRangePicker
- DescriptionList
- Divider
- DocsShell
- EmptyState
- FadeIn
- FieldGroup
- Figure
- Flex
- Form
- Grid
- Icon
- IconButton
- Image
- LineChart
- Link
- MarketingShell
- PageHeader
- PageShell
- Pagination
- Panel
- PortfolioShell
- ProgressBar
- RadioGroup
- ResponsiveGrid
- Row
- SafeArea
- ScaleIn
- SearchBox
- Section
- Select
- Skeleton
- SlideIn
- Spacer
- Spinner
- Stack
- StatCard
- StatusBadge
- Switch
- SwitchRow
- Table
- TableCell
- TableElement
- TableRow
- Tabs
- TextArea
- TextField
- ThreeScene
- Timeline
- Toast
- Tooltip
- Topbar
- UsageMeter
- Video
- Wrap
Constructors
Properties
-
children
→ List<
FlintNode> -
Child nodes rendered inside the element.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ Map<
String, Object?> -
Element attributes, event handlers, classes, and styles.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
HTML tag name for this element.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited