ThreeScene class

Canvas element intended for a browser Three.js renderer.

Inheritance

Constructors

ThreeScene({ThreeSceneController? controller, int width = 640, int height = 360, String? className, String? label, Map<String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle})
Creates a Three.js scene canvas.

Properties

children List<FlintNode>
Child nodes rendered inside the element.
finalinherited
controller ThreeSceneController?
Optional scene controller.
final
hashCode int
The hash code for this object.
no setterinherited
props Map<String, Object?>
Element attributes, event handlers, classes, and styles.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
HTML tag name for this element.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited