includeScopedStyles property
Whether collected scoped styles should be prepended to the rendered HTML.
Implementation
final bool includeScopedStyles;
Whether collected scoped styles should be prepended to the rendered HTML.
final bool includeScopedStyles;