FlintDocument class
Dart-friendly access to the browser document used by Flint UI apps.
This keeps common document/root reads in Flint UI code instead of requiring
app code to import universal_web for small browser tasks.
Constructors
- FlintDocument()
-
const
Properties
- body → HTMLElement?
-
The document
<body>element.no setter - clientHeight → int
-
Root client height, equivalent to
document.documentElement.clientHeight.no setter - clientWidth → int
-
Root client width, equivalent to
document.documentElement.clientWidth.no setter - documentElement → Element?
-
The browser document root, equivalent to JavaScript
document.documentElement.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- hasHorizontalOverflow → bool
-
Whether the document root is horizontally wider than its viewport box.
no setter
- head → HTMLHeadElement?
-
The document
<head>element.no setter - raw → Document
-
The underlying browser
document.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollHeight → int
-
Root scroll height, equivalent to
document.documentElement.scrollHeight.no setter - scrollWidth → int
-
Root scroll width, equivalent to
document.documentElement.scrollWidth.no setter - title ↔ String
-
The current document title.
getter/setter pair
Methods
-
getElementById(
String id) → Element? - Finds an element by id.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
querySelector(
String selector) → Element? -
Finds the first element matching
selector. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited