FlintElement class
DOM element node with a tag, properties, and children.
- Inheritance
- Implementers
- Alert
- AppShell
- AspectRatioBox
- AuthShell
- Avatar
- Box
- Breadcrumbs
- Button
- ButtonGroup
- Center
- Checkbox
- Column
- ConfirmAction
- ConstrainedBox
- Container
- DashboardShell
- DescriptionList
- Divider
- DocsShell
- Drawer
- EmptyState
- FieldGroup
- Figure
- Form
- Grid
- Icon
- IconButton
- Image
- Link
- MarketingShell
- Modal
- PageHeader
- PageShell
- Pagination
- Panel
- Popover
- PortfolioShell
- ProgressBar
- RadioGroup
- ResponsiveGrid
- Row
- SafeArea
- SearchBox
- Section
- Select
- Sidebar
- Skeleton
- Spacer
- Spinner
- Stack
- StatCard
- StatusBadge
- Table
- Tabs
- TextArea
- TextField
- Timeline
- Toast
- Tooltip
- Topbar
- UsageMeter
- Wrap
Constructors
Properties
-
children
→ List<
FlintNode> -
Child nodes rendered inside the element.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ Map<
String, Object?> -
Element attributes, event handlers, classes, and styles.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
HTML tag name for this element.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited