FlintServerRenderer class
Renders Flint UI nodes and components to an HTML string on the server.
Constructors
- FlintServerRenderer({bool includeScopedStyles = true})
-
Creates a server renderer.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeScopedStyles → bool
-
Whether collected scoped styles should be prepended to the rendered HTML.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
Object? value) → String - Renders any Flint renderable value to HTML.
-
renderPage(
FlintComponentRegistry registry, String component, {Map< String, dynamic> props = const {}, FlintComponent missingPage(String component)?}) → String - Renders a registered page component to HTML.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited